==> axis2-1.8.0-src.zip: axis2-1.8.0/modules/transport/base/src/test/java/org/apache/axis2/format/ManagedDataSourceFactoryTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.axis2.format;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.activation.DataSource;

import junit.framework.TestCase;

public class ManagedDataSourceFactoryTest extends TestCase {
    /**
     * Test that exceptions thrown by {@link DataSource#getInputStream()} are
     * correctly propagated. Since {@link ManagedDataSourceFactory} uses dynamic
     * proxies this aspect needs particular attention.
     */
    public void testExceptionPropagation() {
        ManagedDataSource ds = ManagedDataSourceFactory.create(new DataSource() {
            public String getContentType() {
                return null;
            }

            public InputStream getInputStream() throws IOException {
                throw new IOException("TEST");
            }

            public OutputStream getOutputStream() throws IOException {
                return null;
            }
            
            public String getName() {
                return null;
            }
        });
        try {
            ds.getInputStream();
        } catch (IOException ex) {
            assertEquals("TEST", ex.getMessage());
        }
    }
}

==> axis2-2.0.0-src.zip: axis2-2.0.0/modules/transport/base/src/test/java/org/apache/axis2/format/ManagedDataSourceFactoryTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.axis2.format;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import jakarta.activation.DataSource;

import junit.framework.TestCase;

public class ManagedDataSourceFactoryTest extends TestCase {
    /**
     * Test that exceptions thrown by {@link DataSource#getInputStream()} are
     * correctly propagated. Since {@link ManagedDataSourceFactory} uses dynamic
     * proxies this aspect needs particular attention.
     */
    public void testExceptionPropagation() {
        ManagedDataSource ds = ManagedDataSourceFactory.create(new DataSource() {
            public String getContentType() {
                return null;
            }

            public InputStream getInputStream() throws IOException {
                throw new IOException("TEST");
            }

            public OutputStream getOutputStream() throws IOException {
                return null;
            }
            
            public String getName() {
                return null;
            }
        });
        try {
            ds.getInputStream();
        } catch (IOException ex) {
            assertEquals("TEST", ex.getMessage());
        }
    }
}
